==> libkgapi-17.03.90.tar.xz: libkgapi-17.03.90/examples/staticmaps/mainwindow.h <==
/*
    Copyright (C) 2012  Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>
#include <QtGui/QPixmap>

#include <libkgapi2/staticmaps/staticmaptilefetchjob.h>
#include <libkgapi2/staticmaps/staticmapmarker.h>

namespace Ui
{
class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

  public:
    explicit MainWindow(QWidget * parent = 0);
    virtual ~MainWindow();

  public Q_SLOTS:
    void getImage();
    void addMarker();
    void slotTileFetched(KGAPI2::Job*);

  private:
    Ui::MainWindow * m_ui;

    QList<KGAPI2::StaticMapMarker> m_markers;
};

#endif // MAINWINDOW_H

==> libkgapi-17.08.1.tar.xz: libkgapi-17.08.1/examples/staticmaps/mainwindow.h <==
/*
    Copyright (C) 2012  Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QPixmap>

#include <libkgapi2/staticmaps/staticmaptilefetchjob.h>
#include <libkgapi2/staticmaps/staticmapmarker.h>

namespace Ui
{
class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

  public:
    explicit MainWindow(QWidget * parent = nullptr);
    virtual ~MainWindow();

  public Q_SLOTS:
    void getImage();
    void addMarker();
    void slotTileFetched(KGAPI2::Job*);

  private:
    Ui::MainWindow * m_ui;

    QList<KGAPI2::StaticMapMarker> m_markers;
};

#endif // MAINWINDOW_H
